This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch/rfc] ``struct complaint'' -> ``struct deprecated_complaint''


Hello,

This mechanical change is so that the old complain() mechanism is more clearly deprecated. You can't do a complain() call without declaring a ``struct deprecated_complaint'' :-)

I'll commit it in a day or so.

For those that are wondering, the big improvement that comes with the new interface, vis:

extern void complaint (struct complaints **complaints, const char *fmt,
...) ATTR_FORMAT (printf, 2, 3);

is the ATTR_FORMAT(). It eliminates the risk of a complain call having a botched printf format string.

Andrew
2002-10-22  Andrew Cagney  <cagney@redhat.com>

	* complaints.h (struct deprecated_complaint): Rename `struct
	complaint'.
	* complaints.c (complain): Update.
	* remote-vx68.c, remote-vxmips.c, remote-vxsparc.c: Delete
	incorrect comment indicating that "symfile.h" was being included
	for the `struct complaint' definition.
	* remote-vx.c: Update.
	* objc-lang.c: Update.
	* xcoffread.c: Update.
	* hpread.c: Update.
	* mdebugread.c: Update.
	* stabsread.c: Update.
	* dwarf2read.c: Update.
	* dwarfread.c: Update.
	* elfread.c: Update.
	* coffread.c: Update.
	* stabsread.h: Update.
	* dbxread.c: Update.
	* buildsym.c: Update.
	* gdbtypes.c: Update.
	* macrotab.c: Update.

Index: buildsym.c
===================================================================
RCS file: /cvs/src/src/gdb/buildsym.c,v
retrieving revision 1.20
diff -u -r1.20 buildsym.c
--- buildsym.c	10 Sep 2002 23:45:26 -0000	1.20
+++ buildsym.c	22 Oct 2002 18:19:28 -0000
@@ -30,7 +30,7 @@
 #include "bfd.h"
 #include "gdb_obstack.h"
 #include "symtab.h"
-#include "symfile.h"		/* Needed for "struct complaint" */
+#include "symfile.h"
 #include "objfiles.h"
 #include "gdbtypes.h"
 #include "complaints.h"
@@ -74,19 +74,19 @@
 
 /* Complaints about the symbols we have encountered.  */
 
-struct complaint block_end_complaint =
+struct deprecated_complaint block_end_complaint =
 {"block end address less than block start address in %s (patched it)", 0, 0};
 
-struct complaint anon_block_end_complaint =
+struct deprecated_complaint anon_block_end_complaint =
 {"block end address 0x%lx less than block start address 0x%lx (patched it)", 0, 0};
 
-struct complaint innerblock_complaint =
+struct deprecated_complaint innerblock_complaint =
 {"inner block not inside outer block in %s", 0, 0};
 
-struct complaint innerblock_anon_complaint =
+struct deprecated_complaint innerblock_anon_complaint =
 {"inner block (0x%lx-0x%lx) not inside outer block (0x%lx-0x%lx)", 0, 0};
 
-struct complaint blockvector_complaint =
+struct deprecated_complaint blockvector_complaint =
 {"block at %s out of order", 0, 0};
 
 /* maintain the lists of symbols and blocks */
@@ -869,7 +869,7 @@
 	     same.  FIXME: Find out why it is happening.  This is not
 	     believed to happen in most cases (even for coffread.c);
 	     it used to be an abort().  */
-	  static struct complaint msg =
+	  static struct deprecated_complaint msg =
 	  {"Context stack not empty in end_symtab", 0, 0};
 	  complain (&msg);
 	  context_stack_depth = 0;
Index: coffread.c
===================================================================
RCS file: /cvs/src/src/gdb/coffread.c,v
retrieving revision 1.29
diff -u -r1.29 coffread.c
--- coffread.c	22 Aug 2002 05:50:11 -0000	1.29
+++ coffread.c	22 Oct 2002 18:19:29 -0000
@@ -124,37 +124,37 @@
 
 /* Complaints about various problems in the file being read  */
 
-struct complaint ef_complaint =
+struct deprecated_complaint ef_complaint =
 {"Unmatched .ef symbol(s) ignored starting at symnum %d", 0, 0};
 
-struct complaint ef_stack_complaint =
+struct deprecated_complaint ef_stack_complaint =
 {"`.ef' symbol without matching `.bf' symbol ignored starting at symnum %d", 0, 0};
 
-struct complaint eb_stack_complaint =
+struct deprecated_complaint eb_stack_complaint =
 {"`.eb' symbol without matching `.bb' symbol ignored starting at symnum %d", 0, 0};
 
-struct complaint bf_no_aux_complaint =
+struct deprecated_complaint bf_no_aux_complaint =
 {"`.bf' symbol %d has no aux entry", 0, 0};
 
-struct complaint ef_no_aux_complaint =
+struct deprecated_complaint ef_no_aux_complaint =
 {"`.ef' symbol %d has no aux entry", 0, 0};
 
-struct complaint lineno_complaint =
+struct deprecated_complaint lineno_complaint =
 {"Line number pointer %d lower than start of line numbers", 0, 0};
 
-struct complaint unexpected_type_complaint =
+struct deprecated_complaint unexpected_type_complaint =
 {"Unexpected type for symbol %s", 0, 0};
 
-struct complaint bad_sclass_complaint =
+struct deprecated_complaint bad_sclass_complaint =
 {"Bad n_sclass for symbol %s", 0, 0};
 
-struct complaint misordered_blocks_complaint =
+struct deprecated_complaint misordered_blocks_complaint =
 {"Blocks out of order at address %x", 0, 0};
 
-struct complaint tagndx_bad_complaint =
+struct deprecated_complaint tagndx_bad_complaint =
 {"Symbol table entry for %s has bad tagndx value", 0, 0};
 
-struct complaint eb_complaint =
+struct deprecated_complaint eb_complaint =
 {"Mismatched .eb symbol ignored starting at symnum %d", 0, 0};
 
 /* Simplified internal version of coff symbol table information */
Index: complaints.c
===================================================================
RCS file: /cvs/src/src/gdb/complaints.c,v
retrieving revision 1.8
diff -u -r1.8 complaints.c
--- complaints.c	21 Sep 2002 16:36:33 -0000	1.8
+++ complaints.c	22 Oct 2002 18:19:29 -0000
@@ -250,7 +250,7 @@
 }
 
 void
-complain (struct complaint *complaint, ...)
+complain (struct deprecated_complaint *complaint, ...)
 {
   va_list args;
   va_start (args, complaint);
Index: dbxread.c
===================================================================
RCS file: /cvs/src/src/gdb/dbxread.c,v
retrieving revision 1.35
diff -u -r1.35 dbxread.c
--- dbxread.c	18 Sep 2002 20:47:39 -0000	1.35
+++ dbxread.c	22 Oct 2002 18:19:31 -0000
@@ -167,34 +167,34 @@
 
 /* Complaints about the symbols we have encountered.  */
 
-struct complaint lbrac_complaint =
+struct deprecated_complaint lbrac_complaint =
 {"bad block start address patched", 0, 0};
 
-struct complaint string_table_offset_complaint =
+struct deprecated_complaint string_table_offset_complaint =
 {"bad string table offset in symbol %d", 0, 0};
 
-struct complaint unknown_symtype_complaint =
+struct deprecated_complaint unknown_symtype_complaint =
 {"unknown symbol type %s", 0, 0};
 
-struct complaint unknown_symchar_complaint =
+struct deprecated_complaint unknown_symchar_complaint =
 {"unknown symbol descriptor `%c'", 0, 0};
 
-struct complaint lbrac_rbrac_complaint =
+struct deprecated_complaint lbrac_rbrac_complaint =
 {"block start larger than block end", 0, 0};
 
-struct complaint lbrac_unmatched_complaint =
+struct deprecated_complaint lbrac_unmatched_complaint =
 {"unmatched N_LBRAC before symtab pos %d", 0, 0};
 
-struct complaint lbrac_mismatch_complaint =
+struct deprecated_complaint lbrac_mismatch_complaint =
 {"N_LBRAC/N_RBRAC symbol mismatch at symtab pos %d", 0, 0};
 
-struct complaint repeated_header_complaint =
+struct deprecated_complaint repeated_header_complaint =
 {"\"repeated\" header file %s not previously seen, at symtab pos %d", 0, 0};
 
-struct complaint unclaimed_bincl_complaint =
+struct deprecated_complaint unclaimed_bincl_complaint =
 {"N_BINCL %s not in entries for any file, at symtab pos %d", 0, 0};
 
-struct complaint discarding_local_symbols_complaint =
+struct deprecated_complaint discarding_local_symbols_complaint =
 {"misplaced N_LBRAC entry; discarding local symbols which have no enclosing block", 0, 0};
 
 /* find_text_range --- find start and end of loadable code sections
@@ -1360,7 +1360,7 @@
 
       switch (nlist.n_type)
 	{
-	  static struct complaint function_outside_compilation_unit = {
+	  static struct deprecated_complaint function_outside_compilation_unit = {
 	    "function `%s' appears to be defined outside of all compilation units", 0, 0
 	  };
 	  char *p;
Index: dwarf2read.c
===================================================================
RCS file: /cvs/src/src/gdb/dwarf2read.c,v
retrieving revision 1.70
diff -u -r1.70 dwarf2read.c
--- dwarf2read.c	21 Oct 2002 19:11:50 -0000	1.70
+++ dwarf2read.c	22 Oct 2002 18:19:35 -0000
@@ -561,135 +561,135 @@
 
 /* Various complaints about symbol reading that don't abort the process */
 
-static struct complaint dwarf2_const_ignored =
+static struct deprecated_complaint dwarf2_const_ignored =
 {
   "type qualifier 'const' ignored", 0, 0
 };
-static struct complaint dwarf2_volatile_ignored =
+static struct deprecated_complaint dwarf2_volatile_ignored =
 {
   "type qualifier 'volatile' ignored", 0, 0
 };
-static struct complaint dwarf2_non_const_array_bound_ignored =
+static struct deprecated_complaint dwarf2_non_const_array_bound_ignored =
 {
   "non-constant array bounds form '%s' ignored", 0, 0
 };
-static struct complaint dwarf2_missing_line_number_section =
+static struct deprecated_complaint dwarf2_missing_line_number_section =
 {
   "missing .debug_line section", 0, 0
 };
-static struct complaint dwarf2_statement_list_fits_in_line_number_section =
+static struct deprecated_complaint dwarf2_statement_list_fits_in_line_number_section =
 {
   "statement list doesn't fit in .debug_line section", 0, 0
 };
-static struct complaint dwarf2_mangled_line_number_section =
+static struct deprecated_complaint dwarf2_mangled_line_number_section =
 {
   "mangled .debug_line section", 0, 0
 };
-static struct complaint dwarf2_unsupported_die_ref_attr =
+static struct deprecated_complaint dwarf2_unsupported_die_ref_attr =
 {
   "unsupported die ref attribute form: '%s'", 0, 0
 };
-static struct complaint dwarf2_unsupported_stack_op =
+static struct deprecated_complaint dwarf2_unsupported_stack_op =
 {
   "unsupported stack op: '%s'", 0, 0
 };
-static struct complaint dwarf2_complex_location_expr =
+static struct deprecated_complaint dwarf2_complex_location_expr =
 {
   "location expression too complex", 0, 0
 };
-static struct complaint dwarf2_unsupported_tag =
+static struct deprecated_complaint dwarf2_unsupported_tag =
 {
   "unsupported tag: '%s'", 0, 0
 };
-static struct complaint dwarf2_unsupported_at_encoding =
+static struct deprecated_complaint dwarf2_unsupported_at_encoding =
 {
   "unsupported DW_AT_encoding: '%s'", 0, 0
 };
-static struct complaint dwarf2_unsupported_at_frame_base =
+static struct deprecated_complaint dwarf2_unsupported_at_frame_base =
 {
   "unsupported DW_AT_frame_base for function '%s'", 0, 0
 };
-static struct complaint dwarf2_unexpected_tag =
+static struct deprecated_complaint dwarf2_unexpected_tag =
 {
   "unexepected tag in read_type_die: '%s'", 0, 0
 };
-static struct complaint dwarf2_missing_at_frame_base =
+static struct deprecated_complaint dwarf2_missing_at_frame_base =
 {
   "DW_AT_frame_base missing for DW_OP_fbreg", 0, 0
 };
-static struct complaint dwarf2_bad_static_member_name =
+static struct deprecated_complaint dwarf2_bad_static_member_name =
 {
   "unrecognized static data member name '%s'", 0, 0
 };
-static struct complaint dwarf2_unsupported_accessibility =
+static struct deprecated_complaint dwarf2_unsupported_accessibility =
 {
   "unsupported accessibility %d", 0, 0
 };
-static struct complaint dwarf2_bad_member_name_complaint =
+static struct deprecated_complaint dwarf2_bad_member_name_complaint =
 {
   "cannot extract member name from '%s'", 0, 0
 };
-static struct complaint dwarf2_missing_member_fn_type_complaint =
+static struct deprecated_complaint dwarf2_missing_member_fn_type_complaint =
 {
   "member function type missing for '%s'", 0, 0
 };
-static struct complaint dwarf2_vtbl_not_found_complaint =
+static struct deprecated_complaint dwarf2_vtbl_not_found_complaint =
 {
   "virtual function table pointer not found when defining class '%s'", 0, 0
 };
-static struct complaint dwarf2_absolute_sibling_complaint =
+static struct deprecated_complaint dwarf2_absolute_sibling_complaint =
 {
   "ignoring absolute DW_AT_sibling", 0, 0
 };
-static struct complaint dwarf2_const_value_length_mismatch =
+static struct deprecated_complaint dwarf2_const_value_length_mismatch =
 {
   "const value length mismatch for '%s', got %d, expected %d", 0, 0
 };
-static struct complaint dwarf2_unsupported_const_value_attr =
+static struct deprecated_complaint dwarf2_unsupported_const_value_attr =
 {
   "unsupported const value attribute form: '%s'", 0, 0
 };
-static struct complaint dwarf2_misplaced_line_number =
+static struct deprecated_complaint dwarf2_misplaced_line_number =
 {
   "misplaced first line number at 0x%lx for '%s'", 0, 0
 };
-static struct complaint dwarf2_line_header_too_long =
+static struct deprecated_complaint dwarf2_line_header_too_long =
 {
   "line number info header doesn't fit in `.debug_line' section", 0, 0
 };
-static struct complaint dwarf2_missing_macinfo_section =
+static struct deprecated_complaint dwarf2_missing_macinfo_section =
 {
   "missing .debug_macinfo section", 0, 0
 };
-static struct complaint dwarf2_macros_too_long =
+static struct deprecated_complaint dwarf2_macros_too_long =
 {
   "macro info runs off end of `.debug_macinfo' section", 0, 0
 };
-static struct complaint dwarf2_macros_not_terminated =
+static struct deprecated_complaint dwarf2_macros_not_terminated =
 {
   "no terminating 0-type entry for macros in `.debug_macinfo' section", 0, 0
 };
-static struct complaint dwarf2_macro_outside_file =
+static struct deprecated_complaint dwarf2_macro_outside_file =
 {
   "debug info gives macro %s outside of any file: %s", 0, 0
 };
-static struct complaint dwarf2_macro_unmatched_end_file =
+static struct deprecated_complaint dwarf2_macro_unmatched_end_file =
 {
   "macro debug info has an unmatched `close_file' directive", 0, 0
 };
-static struct complaint dwarf2_macro_malformed_definition =
+static struct deprecated_complaint dwarf2_macro_malformed_definition =
 {
   "macro debug info contains a malformed macro definition:\n`%s'", 0, 0
 };
-static struct complaint dwarf2_macro_spaces_in_definition =
+static struct deprecated_complaint dwarf2_macro_spaces_in_definition =
 {
   "macro definition contains spaces in formal argument list:\n`%s'", 0, 0
 };
-static struct complaint dwarf2_invalid_attrib_class =
+static struct deprecated_complaint dwarf2_invalid_attrib_class =
 {
   "invalid attribute class or form for '%s' in '%s'", 0, 0
 };
-static struct complaint dwarf2_invalid_pointer_size = 
+static struct deprecated_complaint dwarf2_invalid_pointer_size = 
 {
   "invalid pointer size %d", 0, 0
 };
Index: dwarfread.c
===================================================================
RCS file: /cvs/src/src/gdb/dwarfread.c,v
retrieving revision 1.14
diff -u -r1.14 dwarfread.c
--- dwarfread.c	1 Aug 2002 17:18:32 -0000	1.14
+++ dwarfread.c	22 Oct 2002 18:19:36 -0000
@@ -62,112 +62,112 @@
 
 /* Complaints that can be issued during DWARF debug info reading. */
 
-struct complaint no_bfd_get_N =
+struct deprecated_complaint no_bfd_get_N =
 {
   "DIE @ 0x%x \"%s\", no bfd support for %d byte data object", 0, 0
 };
 
-struct complaint malformed_die =
+struct deprecated_complaint malformed_die =
 {
   "DIE @ 0x%x \"%s\", malformed DIE, bad length (%d bytes)", 0, 0
 };
 
-struct complaint bad_die_ref =
+struct deprecated_complaint bad_die_ref =
 {
   "DIE @ 0x%x \"%s\", reference to DIE (0x%x) outside compilation unit", 0, 0
 };
 
-struct complaint unknown_attribute_form =
+struct deprecated_complaint unknown_attribute_form =
 {
   "DIE @ 0x%x \"%s\", unknown attribute form (0x%x)", 0, 0
 };
 
-struct complaint unknown_attribute_length =
+struct deprecated_complaint unknown_attribute_length =
 {
   "DIE @ 0x%x \"%s\", unknown attribute length, skipped remaining attributes", 0, 0
 };
 
-struct complaint unexpected_fund_type =
+struct deprecated_complaint unexpected_fund_type =
 {
   "DIE @ 0x%x \"%s\", unexpected fundamental type 0x%x", 0, 0
 };
 
-struct complaint unknown_type_modifier =
+struct deprecated_complaint unknown_type_modifier =
 {
   "DIE @ 0x%x \"%s\", unknown type modifier %u", 0, 0
 };
 
-struct complaint volatile_ignored =
+struct deprecated_complaint volatile_ignored =
 {
   "DIE @ 0x%x \"%s\", type modifier 'volatile' ignored", 0, 0
 };
 
-struct complaint const_ignored =
+struct deprecated_complaint const_ignored =
 {
   "DIE @ 0x%x \"%s\", type modifier 'const' ignored", 0, 0
 };
 
-struct complaint botched_modified_type =
+struct deprecated_complaint botched_modified_type =
 {
   "DIE @ 0x%x \"%s\", botched modified type decoding (mtype 0x%x)", 0, 0
 };
 
-struct complaint op_deref2 =
+struct deprecated_complaint op_deref2 =
 {
   "DIE @ 0x%x \"%s\", OP_DEREF2 address 0x%x not handled", 0, 0
 };
 
-struct complaint op_deref4 =
+struct deprecated_complaint op_deref4 =
 {
   "DIE @ 0x%x \"%s\", OP_DEREF4 address 0x%x not handled", 0, 0
 };
 
-struct complaint basereg_not_handled =
+struct deprecated_complaint basereg_not_handled =
 {
   "DIE @ 0x%x \"%s\", BASEREG %d not handled", 0, 0
 };
 
-struct complaint dup_user_type_allocation =
+struct deprecated_complaint dup_user_type_allocation =
 {
   "DIE @ 0x%x \"%s\", internal error: duplicate user type allocation", 0, 0
 };
 
-struct complaint dup_user_type_definition =
+struct deprecated_complaint dup_user_type_definition =
 {
   "DIE @ 0x%x \"%s\", internal error: duplicate user type definition", 0, 0
 };
 
-struct complaint missing_tag =
+struct deprecated_complaint missing_tag =
 {
   "DIE @ 0x%x \"%s\", missing class, structure, or union tag", 0, 0
 };
 
-struct complaint bad_array_element_type =
+struct deprecated_complaint bad_array_element_type =
 {
   "DIE @ 0x%x \"%s\", bad array element type attribute 0x%x", 0, 0
 };
 
-struct complaint subscript_data_items =
+struct deprecated_complaint subscript_data_items =
 {
   "DIE @ 0x%x \"%s\", can't decode subscript data items", 0, 0
 };
 
-struct complaint unhandled_array_subscript_format =
+struct deprecated_complaint unhandled_array_subscript_format =
 {
   "DIE @ 0x%x \"%s\", array subscript format 0x%x not handled yet", 0, 0
 };
 
-struct complaint unknown_array_subscript_format =
+struct deprecated_complaint unknown_array_subscript_format =
 {
   "DIE @ 0x%x \"%s\", unknown array subscript format %x", 0, 0
 };
 
-struct complaint not_row_major =
+struct deprecated_complaint not_row_major =
 {
   "DIE @ 0x%x \"%s\", array not row major; not handled correctly", 0, 0
 };
 
-struct complaint missing_at_name =
+struct deprecated_complaint missing_at_name =
 {
   "DIE @ 0x%x, AT_name tag missing", 0, 0
 };
Index: elfread.c
===================================================================
RCS file: /cvs/src/src/gdb/elfread.c,v
retrieving revision 1.25
diff -u -r1.25 elfread.c
--- elfread.c	19 Sep 2002 03:58:41 -0000	1.25
+++ elfread.c	22 Oct 2002 18:19:36 -0000
@@ -54,16 +54,16 @@
 
 /* Various things we might complain about... */
 
-struct complaint section_info_complaint =
+struct deprecated_complaint section_info_complaint =
 {"elf/stab section information %s without a preceding file symbol", 0, 0};
 
-struct complaint section_info_dup_complaint =
+struct deprecated_complaint section_info_dup_complaint =
 {"duplicated elf/stab section information for %s", 0, 0};
 
-struct complaint stab_info_mismatch_complaint =
+struct deprecated_complaint stab_info_mismatch_complaint =
 {"elf/stab section information missing for %s", 0, 0};
 
-struct complaint stab_info_questionable_complaint =
+struct deprecated_complaint stab_info_questionable_complaint =
 {"elf/stab section information questionable for %s", 0, 0};
 
 static void free_elfinfo (void *);
Index: gdbtypes.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbtypes.c,v
retrieving revision 1.60
diff -u -r1.60 gdbtypes.c
--- gdbtypes.c	16 Oct 2002 20:50:22 -0000	1.60
+++ gdbtypes.c	22 Oct 2002 18:19:38 -0000
@@ -1337,7 +1337,7 @@
    This used to be coded as a macro, but I don't think it is called 
    often enough to merit such treatment.  */
 
-struct complaint stub_noname_complaint =
+struct deprecated_complaint stub_noname_complaint =
 {"stub type has NULL name", 0, 0};
 
 struct type *
@@ -1508,7 +1508,7 @@
 	default:
 	  {
 
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {"Bad int type code length x%x\n", 0, 0};
 
 	    complain (&msg, tlen);
@@ -1530,7 +1530,7 @@
 	  break;
 	default:
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {"Bad float type code length x%x\n", 0, 0};
 	    complain (&msg, tlen);
 	  }
@@ -1546,7 +1546,7 @@
       break;
     case TYPE_CODE_TYPEDEF:
       {
-	static struct complaint msg =
+	static struct deprecated_complaint msg =
 	{"Typedefs in overloaded functions not yet supported\n", 0, 0};
 	complain (&msg);
       }
@@ -1586,7 +1586,7 @@
     case TYPE_CODE_ERROR:
     default:
       {
-	static struct complaint msg =
+	static struct deprecated_complaint msg =
 	{"Unknown type code x%x\n", 0, 0};
 	complain (&msg, tcode);
       }
Index: hpread.c
===================================================================
RCS file: /cvs/src/src/gdb/hpread.c,v
retrieving revision 1.23
diff -u -r1.23 hpread.c
--- hpread.c	21 Oct 2002 14:55:18 -0000	1.23
+++ hpread.c	22 Oct 2002 18:19:40 -0000
@@ -129,52 +129,52 @@
 
 /* FIXME: Shouldn't this stuff be in a .h file somewhere?  */
 /* Complaints about the symbols we have encountered.  */
-extern struct complaint string_table_offset_complaint;
-extern struct complaint lbrac_unmatched_complaint;
-extern struct complaint lbrac_mismatch_complaint;
+extern struct deprecated_complaint string_table_offset_complaint;
+extern struct deprecated_complaint lbrac_unmatched_complaint;
+extern struct deprecated_complaint lbrac_mismatch_complaint;
 
-static struct complaint hpread_unhandled_end_common_complaint =
+static struct deprecated_complaint hpread_unhandled_end_common_complaint =
 {
   "unhandled symbol in hp-symtab-read.c: DNTT_TYPE_COMMON/DNTT_TYPE_END.\n", 0, 0
 };
 
-static struct complaint hpread_unhandled_type_complaint =
+static struct deprecated_complaint hpread_unhandled_type_complaint =
 {
   "hpread_type_translate: unhandled type code.", 0, 0
 };
 
-static struct complaint hpread_struct_complaint =
+static struct deprecated_complaint hpread_struct_complaint =
 {
   "hpread_read_struct_type: expected SVAR type...", 0, 0
 };
 
-static struct complaint hpread_array_complaint =
+static struct deprecated_complaint hpread_array_complaint =
 {
   "error in hpread_array_type.", 0, 0
 };
 
-static struct complaint hpread_type_lookup_complaint =
+static struct deprecated_complaint hpread_type_lookup_complaint =
 {
   "error in hpread_type_lookup().", 0, 0
 };
 
 
-static struct complaint hpread_unexpected_end_complaint =
+static struct deprecated_complaint hpread_unexpected_end_complaint =
 {
   "internal error in hp-symtab-read.c: Unexpected DNTT_TYPE_END kind.", 0, 0
 };
 
-static struct complaint hpread_tagdef_complaint =
+static struct deprecated_complaint hpread_tagdef_complaint =
 {
   "error processing class tagdef", 0, 0
 };
 
-static struct complaint hpread_unhandled_common_complaint =
+static struct deprecated_complaint hpread_unhandled_common_complaint =
 {
   "unhandled symbol in hp-symtab-read.c: DNTT_TYPE_COMMON.", 0, 0
 };
 
-static struct complaint hpread_unhandled_blockdata_complaint =
+static struct deprecated_complaint hpread_unhandled_blockdata_complaint =
 {
   "unhandled symbol in hp-symtab-read.c: DNTT_TYPE_BLOCKDATA.", 0, 0
 };
Index: macrotab.c
===================================================================
RCS file: /cvs/src/src/gdb/macrotab.c,v
retrieving revision 1.5
diff -u -r1.5 macrotab.c
--- macrotab.c	29 Jul 2002 22:55:26 -0000	1.5
+++ macrotab.c	22 Oct 2002 18:19:40 -0000
@@ -445,7 +445,7 @@
          should tolerate bad debug info.  So:
 
          First, squawk.  */
-      static struct complaint bogus_inclusion_line = {
+      static struct deprecated_complaint bogus_inclusion_line = {
         "both `%s' and `%s' allegedly #included at %s:%d", 0, 0
       };
 
@@ -707,7 +707,7 @@
 
       if (! same)
         {
-          static struct complaint macro_redefined = {
+          static struct deprecated_complaint macro_redefined = {
             "macro `%s' redefined at %s:%d; original definition at %s:%d",
             0, 0
           };
@@ -801,7 +801,7 @@
 
       if (key->end_file)
         {
-          static struct complaint double_undef = {
+          static struct deprecated_complaint double_undef = {
             "macro '%s' is #undefined twice, at %s:%d and %s:%d",
             0, 0
           };
@@ -820,7 +820,7 @@
          has no macro definition in scope is ignored.  So we should
          ignore it too.  */
 #if 0
-      static struct complaint no_macro_to_undefine = {
+      static struct deprecated_complaint no_macro_to_undefine = {
         "no definition for macro `%s' in scope to #undef at %s:%d",
         0, 0
       };
Index: mdebugread.c
===================================================================
RCS file: /cvs/src/src/gdb/mdebugread.c,v
retrieving revision 1.29
diff -u -r1.29 mdebugread.c
--- mdebugread.c	18 Sep 2002 20:47:39 -0000	1.29
+++ mdebugread.c	22 Oct 2002 18:19:42 -0000
@@ -143,94 +143,94 @@
 
 /* Various complaints about symbol reading that don't abort the process */
 
-static struct complaint bad_file_number_complaint =
+static struct deprecated_complaint bad_file_number_complaint =
 {"bad file number %d", 0, 0};
 
-static struct complaint index_complaint =
+static struct deprecated_complaint index_complaint =
 {"bad aux index at symbol %s", 0, 0};
 
-static struct complaint aux_index_complaint =
+static struct deprecated_complaint aux_index_complaint =
 {"bad proc end in aux found from symbol %s", 0, 0};
 
-static struct complaint block_index_complaint =
+static struct deprecated_complaint block_index_complaint =
 {"bad aux index at block symbol %s", 0, 0};
 
-static struct complaint unknown_ext_complaint =
+static struct deprecated_complaint unknown_ext_complaint =
 {"unknown external symbol %s", 0, 0};
 
-static struct complaint unknown_sym_complaint =
+static struct deprecated_complaint unknown_sym_complaint =
 {"unknown local symbol %s", 0, 0};
 
-static struct complaint unknown_st_complaint =
+static struct deprecated_complaint unknown_st_complaint =
 {"with type %d", 0, 0};
 
-static struct complaint block_overflow_complaint =
+static struct deprecated_complaint block_overflow_complaint =
 {"block containing %s overfilled", 0, 0};
 
-static struct complaint basic_type_complaint =
+static struct deprecated_complaint basic_type_complaint =
 {"cannot map ECOFF basic type 0x%x for %s", 0, 0};
 
-static struct complaint unknown_type_qual_complaint =
+static struct deprecated_complaint unknown_type_qual_complaint =
 {"unknown type qualifier 0x%x", 0, 0};
 
-static struct complaint array_index_type_complaint =
+static struct deprecated_complaint array_index_type_complaint =
 {"illegal array index type for %s, assuming int", 0, 0};
 
-static struct complaint bad_tag_guess_complaint =
+static struct deprecated_complaint bad_tag_guess_complaint =
 {"guessed tag type of %s incorrectly", 0, 0};
 
-static struct complaint block_member_complaint =
+static struct deprecated_complaint block_member_complaint =
 {"declaration block contains unhandled symbol type %d", 0, 0};
 
-static struct complaint stEnd_complaint =
+static struct deprecated_complaint stEnd_complaint =
 {"stEnd with storage class %d not handled", 0, 0};
 
-static struct complaint unknown_mdebug_symtype_complaint =
+static struct deprecated_complaint unknown_mdebug_symtype_complaint =
 {"unknown symbol type 0x%x", 0, 0};
 
-static struct complaint stab_unknown_complaint =
+static struct deprecated_complaint stab_unknown_complaint =
 {"unknown stabs symbol %s", 0, 0};
 
-static struct complaint pdr_for_nonsymbol_complaint =
+static struct deprecated_complaint pdr_for_nonsymbol_complaint =
 {"PDR for %s, but no symbol", 0, 0};
 
-static struct complaint pdr_static_symbol_complaint =
+static struct deprecated_complaint pdr_static_symbol_complaint =
 {"can't handle PDR for static proc at 0x%lx", 0, 0};
 
-static struct complaint bad_setjmp_pdr_complaint =
+static struct deprecated_complaint bad_setjmp_pdr_complaint =
 {"fixing bad setjmp PDR from libc", 0, 0};
 
-static struct complaint bad_fbitfield_complaint =
+static struct deprecated_complaint bad_fbitfield_complaint =
 {"can't handle TIR fBitfield for %s", 0, 0};
 
-static struct complaint bad_continued_complaint =
+static struct deprecated_complaint bad_continued_complaint =
 {"illegal TIR continued for %s", 0, 0};
 
-static struct complaint bad_rfd_entry_complaint =
+static struct deprecated_complaint bad_rfd_entry_complaint =
 {"bad rfd entry for %s: file %d, index %d", 0, 0};
 
-static struct complaint unexpected_type_code_complaint =
+static struct deprecated_complaint unexpected_type_code_complaint =
 {"unexpected type code for %s", 0, 0};
 
-static struct complaint unable_to_cross_ref_complaint =
+static struct deprecated_complaint unable_to_cross_ref_complaint =
 {"unable to cross ref btTypedef for %s", 0, 0};
 
-static struct complaint bad_indirect_xref_complaint =
+static struct deprecated_complaint bad_indirect_xref_complaint =
 {"unable to cross ref btIndirect for %s", 0, 0};
 
-static struct complaint illegal_forward_tq0_complaint =
+static struct deprecated_complaint illegal_forward_tq0_complaint =
 {"illegal tq0 in forward typedef for %s", 0, 0};
 
-static struct complaint illegal_forward_bt_complaint =
+static struct deprecated_complaint illegal_forward_bt_complaint =
 {"illegal bt %d in forward typedef for %s", 0, 0};
 
-static struct complaint bad_linetable_guess_complaint =
+static struct deprecated_complaint bad_linetable_guess_complaint =
 {"guessed size of linetable for %s incorrectly", 0, 0};
 
-static struct complaint bad_ext_ifd_complaint =
+static struct deprecated_complaint bad_ext_ifd_complaint =
 {"bad ifd for external symbol: %d (max %d)", 0, 0};
 
-static struct complaint bad_ext_iss_complaint =
+static struct deprecated_complaint bad_ext_iss_complaint =
 {"bad iss for external symbol: %ld (max %ld)", 0, 0};
 
 /* Macros and extra defs */
@@ -2720,7 +2720,7 @@
 
 		switch (type_code)
 		  {
-		    static struct complaint function_outside_compilation_unit = {
+		    static struct deprecated_complaint function_outside_compilation_unit = {
 		      "function `%s' appears to be defined outside of all compilation units", 0, 0
 		    };
 		    char *p;
Index: objc-lang.c
===================================================================
RCS file: /cvs/src/src/gdb/objc-lang.c,v
retrieving revision 1.4
diff -u -r1.4 objc-lang.c
--- objc-lang.c	4 Oct 2002 01:18:48 -0000	1.4
+++ objc-lang.c	22 Oct 2002 18:19:43 -0000
@@ -74,11 +74,11 @@
 
 /* Complaints about ObjC classes, selectors, etc.  */
 
-static struct complaint noclass_lookup_complaint = {
+static struct deprecated_complaint noclass_lookup_complaint = {
   "no way to lookup Objective-C classes", 0, 0
 };
 
-static struct complaint nosel_lookup_complaint = {
+static struct deprecated_complaint nosel_lookup_complaint = {
   "no way to lookup Objective-C selectors", 0, 0
 };
 
Index: remote-vx.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-vx.c,v
retrieving revision 1.19
diff -u -r1.19 remote-vx.c
--- remote-vx.c	19 Jan 2002 03:32:40 -0000	1.19
+++ remote-vx.c	22 Oct 2002 18:19:43 -0000
@@ -820,7 +820,7 @@
    Returns status of symbol read on target side (0=success, -1=fail)
    Returns -1 and complain()s if rpc fails.  */
 
-struct complaint cant_contact_target =
+struct deprecated_complaint cant_contact_target =
 {"Lost contact with VxWorks target", 0, 0};
 
 static int
Index: remote-vx68.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-vx68.c,v
retrieving revision 1.6
diff -u -r1.6 remote-vx68.c
--- remote-vx68.c	1 Mar 2001 01:39:21 -0000	1.6
+++ remote-vx68.c	22 Oct 2002 18:19:43 -0000
@@ -30,7 +30,7 @@
 #include "gdbcore.h"
 #include "command.h"
 #include "symtab.h"
-#include "symfile.h"		/* for struct complaint */
+#include "symfile.h"
 #include "regcache.h"
 
 #include "gdb_string.h"
Index: remote-vxmips.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-vxmips.c,v
retrieving revision 1.6
diff -u -r1.6 remote-vxmips.c
--- remote-vxmips.c	1 Mar 2001 01:39:21 -0000	1.6
+++ remote-vxmips.c	22 Oct 2002 18:19:43 -0000
@@ -30,7 +30,7 @@
 #include "gdbcore.h"
 #include "command.h"
 #include "symtab.h"
-#include "symfile.h"		/* for struct complaint */
+#include "symfile.h"
 #include "regcache.h"
 
 #include "gdb_string.h"
Index: remote-vxsparc.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-vxsparc.c,v
retrieving revision 1.7
diff -u -r1.7 remote-vxsparc.c
--- remote-vxsparc.c	24 Apr 2002 05:34:52 -0000	1.7
+++ remote-vxsparc.c	22 Oct 2002 18:19:44 -0000
@@ -30,7 +30,7 @@
 #include "gdbcore.h"
 #include "command.h"
 #include "symtab.h"
-#include "symfile.h"		/* for struct complaint */
+#include "symfile.h"
 #include "regcache.h"
 
 #include "gdb_string.h"
Index: stabsread.c
===================================================================
RCS file: /cvs/src/src/gdb/stabsread.c,v
retrieving revision 1.44
diff -u -r1.44 stabsread.c
--- stabsread.c	18 Oct 2002 22:49:42 -0000	1.44
+++ stabsread.c	22 Oct 2002 18:19:46 -0000
@@ -202,46 +202,46 @@
 #define BELIEVE_PCC_PROMOTION_TYPE 0
 #endif
 
-static struct complaint invalid_cpp_abbrev_complaint =
+static struct deprecated_complaint invalid_cpp_abbrev_complaint =
 {"invalid C++ abbreviation `%s'", 0, 0};
 
-static struct complaint invalid_cpp_type_complaint =
+static struct deprecated_complaint invalid_cpp_type_complaint =
 {"C++ abbreviated type name unknown at symtab pos %d", 0, 0};
 
-static struct complaint member_fn_complaint =
+static struct deprecated_complaint member_fn_complaint =
 {"member function type missing, got '%c'", 0, 0};
 
-static struct complaint const_vol_complaint =
+static struct deprecated_complaint const_vol_complaint =
 {"const/volatile indicator missing, got '%c'", 0, 0};
 
-static struct complaint error_type_complaint =
+static struct deprecated_complaint error_type_complaint =
 {"couldn't parse type; debugger out of date?", 0, 0};
 
-static struct complaint invalid_member_complaint =
+static struct deprecated_complaint invalid_member_complaint =
 {"invalid (minimal) member type data format at symtab pos %d.", 0, 0};
 
-static struct complaint range_type_base_complaint =
+static struct deprecated_complaint range_type_base_complaint =
 {"base type %d of range type is not defined", 0, 0};
 
-static struct complaint reg_value_complaint =
+static struct deprecated_complaint reg_value_complaint =
 {"register number %d too large (max %d) in symbol %s", 0, 0};
 
-static struct complaint vtbl_notfound_complaint =
+static struct deprecated_complaint vtbl_notfound_complaint =
 {"virtual function table pointer not found when defining class `%s'", 0, 0};
 
-static struct complaint unrecognized_cplus_name_complaint =
+static struct deprecated_complaint unrecognized_cplus_name_complaint =
 {"Unknown C++ symbol name `%s'", 0, 0};
 
-static struct complaint rs6000_builtin_complaint =
+static struct deprecated_complaint rs6000_builtin_complaint =
 {"Unknown builtin type %d", 0, 0};
 
-static struct complaint unresolved_sym_chain_complaint =
+static struct deprecated_complaint unresolved_sym_chain_complaint =
 {"%s: common block `%s' from global_sym_chain unresolved", 0, 0};
 
-static struct complaint stabs_general_complaint =
+static struct deprecated_complaint stabs_general_complaint =
 {"%s", 0, 0};
 
-static struct complaint lrs_general_complaint =
+static struct deprecated_complaint lrs_general_complaint =
 {"%s", 0, 0};
 
 /* Make a list of forward references which haven't been defined.  */
@@ -311,7 +311,7 @@
 
   if (filenum < 0 || filenum >= n_this_object_header_files)
     {
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {"\
 Invalid symbol data: type number (%d,%d) out of range at symtab pos %d.",
        0, 0};
@@ -618,11 +618,11 @@
 read_cfront_baseclasses (struct field_info *fip, char **pp, struct type *type,
 			 struct objfile *objfile)
 {
-  static struct complaint msg_unknown =
+  static struct deprecated_complaint msg_unknown =
   {"\
 	 Unsupported token in stabs string %s.\n",
    0, 0};
-  static struct complaint msg_notfound =
+  static struct deprecated_complaint msg_notfound =
   {"\
 	           Unable to find base type for %s.\n",
    0, 0};
@@ -692,7 +692,7 @@
 	  /* Bad visibility format.  Complain and treat it as
 	     public.  */
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {
 	      "Unknown visibility `%c' for baseclass", 0, 0};
 	    complain (&msg, new->visibility);
@@ -810,7 +810,7 @@
       ref_func = lookup_symbol (fname, 0, VAR_NAMESPACE, 0, 0);		/* demangled name */
       if (!ref_func)
 	{
-	  static struct complaint msg =
+	  static struct deprecated_complaint msg =
 	  {"\
       		Unable to find function symbol for %s\n",
 	   0, 0};
@@ -2435,7 +2435,7 @@
 	      {
 		/* Complain and keep going, so compilers can invent new
 		   cross-reference types.  */
-		static struct complaint msg =
+		static struct deprecated_complaint msg =
 		{"Unrecognized cross-reference type `%c'", 0, 0};
 		complain (&msg, (*pp)[0]);
 		code = TYPE_CODE_STRUCT;
@@ -2660,7 +2660,7 @@
           ++*pp;
         else
           {
-            static struct complaint msg = {
+            static struct deprecated_complaint msg = {
               "Prototyped function type didn't end arguments with `#':\n%s",
               0, 0
             };
@@ -4018,7 +4018,7 @@
 	default:
 	  /* Unknown character.  Complain and treat it as non-virtual.  */
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {
 	      "Unknown virtual character `%c' for baseclass", 0, 0};
 	    complain (&msg, **pp);
@@ -4037,7 +4037,7 @@
 	  /* Bad visibility format.  Complain and treat it as
 	     public.  */
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {
 	      "Unknown visibility `%c' for baseclass", 0, 0
 	    };
@@ -4210,7 +4210,7 @@
       ref_static = lookup_symbol (sname, 0, VAR_NAMESPACE, 0, 0);	/*demangled_name */
       if (!ref_static)
 	{
-	  static struct complaint msg =
+	  static struct deprecated_complaint msg =
 	  {"\
       		Unable to find symbol for static data field %s\n",
 	   0, 0};
@@ -4389,7 +4389,7 @@
 	default:
 	  /* Unknown visibility.  Complain and treat it as public.  */
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {
 	      "Unknown visibility `%c' for field", 0, 0};
 	    complain (&msg, fip->list->visibility);
@@ -4402,7 +4402,7 @@
 }
 
 
-static struct complaint multiply_defined_struct =
+static struct deprecated_complaint multiply_defined_struct =
 {"struct/union type gets multiply defined: %s%s", 0, 0};
 
 
@@ -5214,7 +5214,7 @@
 {
   if (common_block_name != NULL)
     {
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {
 	"Invalid symbol data: common block within common block",
 	0, 0};
@@ -5244,7 +5244,7 @@
 
   if (common_block_name == NULL)
     {
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {"ECOMM symbol unmatched by BCOMM", 0, 0};
       complain (&msg);
       return;
@@ -5359,7 +5359,7 @@
 
 		if (typename == NULL)
 		  {
-		    static struct complaint msg =
+		    static struct deprecated_complaint msg =
 		    {"need a type name", 0, 0};
 		    complain (&msg);
 		    break;
@@ -5384,7 +5384,7 @@
 
 	default:
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {"\
 GDB internal error.  cleanup_undefined_types with bad type %d.", 0, 0};
 	    complain (&msg, TYPE_CODE (*type));
Index: stabsread.h
===================================================================
RCS file: /cvs/src/src/gdb/stabsread.h,v
retrieving revision 1.8
diff -u -r1.8 stabsread.h
--- stabsread.h	18 Jul 2002 17:22:50 -0000	1.8
+++ stabsread.h	22 Oct 2002 18:19:46 -0000
@@ -128,8 +128,8 @@
 
 EXTERN int n_allocated_this_object_header_files;
 
-extern struct complaint unknown_symtype_complaint;
-extern struct complaint unknown_symchar_complaint;
+extern struct deprecated_complaint unknown_symtype_complaint;
+extern struct deprecated_complaint unknown_symchar_complaint;
 
 extern struct type *read_type (char **, struct objfile *);
 
Index: xcoffread.c
===================================================================
RCS file: /cvs/src/src/gdb/xcoffread.c,v
retrieving revision 1.20
diff -u -r1.20 xcoffread.c
--- xcoffread.c	12 Jul 2002 18:30:15 -0000	1.20
+++ xcoffread.c	22 Oct 2002 18:19:47 -0000
@@ -150,16 +150,16 @@
     CORE_ADDR toc_offset;
   };
 
-static struct complaint storclass_complaint =
+static struct deprecated_complaint storclass_complaint =
 {"Unexpected storage class: %d", 0, 0};
 
-static struct complaint bf_notfound_complaint =
+static struct deprecated_complaint bf_notfound_complaint =
 {"line numbers off, `.bf' symbol not found", 0, 0};
 
-static struct complaint ef_complaint =
+static struct deprecated_complaint ef_complaint =
 {"Mismatched .ef symbol ignored starting at symnum %d", 0, 0};
 
-static struct complaint eb_complaint =
+static struct deprecated_complaint eb_complaint =
 {"Mismatched .eb symbol ignored starting at symnum %d", 0, 0};
 
 static void xcoff_initial_scan (struct objfile *, int);
@@ -483,7 +483,7 @@
       /* This can happen with old versions of GCC.
          GCC 2.3.3-930426 does not exhibit this on a test case which
          a user said produced the message for him.  */
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {"Nested C_BINCL symbols", 0, 0};
       complain (&msg);
     }
@@ -502,7 +502,7 @@
 
   if (inclDepth == 0)
     {
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {"Mismatched C_BINCL/C_EINCL pair", 0, 0};
       complain (&msg);
     }
@@ -766,7 +766,7 @@
     {
       if (endoffset >= limit_offset)
 	{
-	  static struct complaint msg =
+	  static struct deprecated_complaint msg =
 	  {"Bad line table offset in C_EINCL directive", 0, 0};
 	  complain (&msg);
 	  return;
@@ -864,7 +864,7 @@
 xcoff_next_symbol_text (struct objfile *objfile)
 {
   struct internal_syment symbol;
-  static struct complaint msg =
+  static struct deprecated_complaint msg =
   {"Unexpected symbol continuation", 0, 0};
   char *retval;
   /* FIXME: is this the same as the passed arg? */
@@ -1332,7 +1332,7 @@
 	case C_UNTAG:
 	case C_ENTAG:
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {"Unrecognized storage class %d.", 0, 0};
 	    complain (&msg, cs->c_sclass);
 	  }
@@ -1603,7 +1603,7 @@
   ->symtbl;
   if (symno < 0 || symno >= nsyms)
     {
-      static struct complaint msg =
+      static struct deprecated_complaint msg =
       {"Invalid symbol offset", 0, 0};
       complain (&msg);
       symbol->n_value = 0;
@@ -2442,7 +2442,7 @@
 
 	default:
 	  {
-	    static struct complaint msg =
+	    static struct deprecated_complaint msg =
 	    {"Storage class %d not recognized during scan", 0, 0};
 	    complain (&msg, sclass);
 	  }
@@ -2565,7 +2565,7 @@
 	case C_STSYM:
 	  {
 
-	    static struct complaint function_outside_compilation_unit = {
+	    static struct deprecated_complaint function_outside_compilation_unit = {
 	      "function `%s' appears to be defined outside of all compilation units", 0, 0
 	    };
 

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: complaints.h
===================================================================
RCS file: /cvs/src/src/gdb/complaints.h,v
retrieving revision 1.4
diff -u -r1.4 complaints.h
--- complaints.h	19 Sep 2002 00:42:41 -0000	1.4
+++ complaints.h	22 Oct 2002 18:19:29 -0000
@@ -50,9 +50,15 @@
 			      int less_verbose, int noisy);
 
 
-/* Legacy interfaces to keep the old code working (until it is all
-   converted to the above).  While the structure below contains a
-   number of fields, all but .message are ignored.
+/* Deprecated interfaces to keep the old code working (until it is all
+   converted to the above).  Existing code such as:
+
+     struct deprecated_complaint msg = { "msg", 0, 0 };
+     complaint (&msg);
+
+   should be replaced by:
+
+     complaint (&symtab_complaints, __FILE__, __LINE__, "msg");
 
    Support for complaining about things in the symbol file that aren't
    catastrophic.
@@ -61,13 +67,13 @@
    during a symbol read, we report it.  At the end of symbol reading,
    if verbose, we report how many of each problem we had.  */
 
-struct complaint
+struct deprecated_complaint
 {
   const char *message;
   unsigned counter_ignored;
-  struct complaint *next_ignored;
+  struct deprecated_complaint *next_ignored;
 };
 
-extern void complain (struct complaint *, ...);
+extern void complain (struct deprecated_complaint *, ...);
 
 #endif /* !defined (COMPLAINTS_H) */